package middleware

import (
	"fmt"
	"net/http"

	"wechat-api/ent"
	"wechat-api/internal/utils/contextkey"
	jwtutils "wechat-api/internal/utils/jwt"

	"wechat-api/internal/config"

	baseconfig "github.com/suyuan32/simple-admin-common/config"

	"github.com/redis/go-redis/v9"
	"github.com/suyuan32/simple-admin-common/utils/jwt"
	"github.com/zeromicro/go-zero/core/errorx"
	"github.com/zeromicro/go-zero/core/logx"
	"github.com/zeromicro/go-zero/rest/httpx"
)

/*
//"wechat-api/internal/types/payload"
var p types.payload.SendWxPayload
*/

type OpenAuthorityMiddleware struct {
	DB     *ent.Client
	Rds    redis.UniversalClient
	Config config.Config
}

func NewOpenAuthorityMiddleware(db *ent.Client, rds redis.UniversalClient, c config.Config) *OpenAuthorityMiddleware {
	return &OpenAuthorityMiddleware{
		DB:     db,
		Rds:    rds,
		Config: c,
	}
}

func (m *OpenAuthorityMiddleware) Handle(next http.HandlerFunc) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		// TODO generate middleware implement function, delete after code implementation
		apiToken := jwt.StripBearerPrefixFromToken(r.Header.Get("Authorization"))
		claims, err := jwtutils.ParseJwtToken(m.Config.Auth.AccessSecret, apiToken)
		fmt.Println("claims")
		fmt.Printf("%+v\n", claims)
		if err != nil {
			logx.Errorw("check user auth error", logx.Field("detail", err.Error()))
			httpx.Error(w, errorx.NewApiError(http.StatusInternalServerError, err.Error()))
			return
		}
		ctx := r.Context()
		ctx = contextkey.HttpResponseWriterKey.WithValue(ctx, w) //context存入http.ResponseWriter
		if len(apiToken) > 0 {
			ctx = contextkey.OpenapiTokenKey.WithValue(ctx, apiToken)
		}

		userAgent := r.Header.Get("User-Agent")

		fmt.Printf("In OpenAuthorityMiddlewar:%s,userAgent:%s\n", baseconfig.RedisTokenPrefix+":"+apiToken, userAgent)

		//ctx = context.WithValue(ctx, "HttpResp-Writer", w)
		//ctx = WithOutWriter(ctx, w)
		//httpx.Error(w, errorx.NewApiError(http.StatusInternalServerError, "错误啦"))
		newReq := r.WithContext(ctx)
		// Passthrough to next handler if need
		next(w, newReq)
		//next(w, r)
	}
}
